@@ -26,6 +26,9 @@ FAILEDOPERATION_STARTJOBFAILED = 'FailedOperation.StartJobFailed'
 # 当前状态冲突，不能执行该操作。
 FAILEDOPERATION_STATUSINCONFLICT = 'FailedOperation.StatusInConflict'
 
+# 当前状态不允许操作。
+FAILEDOPERATION_STATUSINCONFLICTERROR = 'FailedOperation.StatusInConflictError'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -44,6 +47,9 @@ INTERNALERROR_DATABASEERROR = 'InternalError.DatabaseError'
 # 迁移任务冲突。
 INTERNALERROR_DUPLICATEJOB = 'InternalError.DuplicateJob'
 
+# 内部组件访问错误。
+INTERNALERROR_INTERNALINNERCOMMONERROR = 'InternalError.InternalInnerCommonError'
+
 # 锁冲突。
 INTERNALERROR_LOCKERROR = 'InternalError.LockError'
 
@@ -65,6 +71,12 @@ INVALIDPARAMETER_BIZINVALIDPARAMETERVALUEERROR = 'InvalidParameter.BizInvalidPar
 # 实例不存在。
 INVALIDPARAMETER_INSTANCENOTFOUND = 'InvalidParameter.InstanceNotFound'
 
+# 业务参数错误。
+INVALIDPARAMETERVALUE_BIZINVALIDPARAMETERVALUEERROR = 'InvalidParameterValue.BizInvalidParameterValueError'
+
+# 数据转换错误。
+INVALIDPARAMETERVALUE_DATACONVERTERROR = 'InvalidParameterValue.DataConvertError'
+
 # 参数值错误。
 INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUE = 'InvalidParameterValue.InvalidParameterValue'
 
@@ -74,6 +86,9 @@ LIMITEXCEEDED_MAXUNUSEDJOBS = 'LimitExceeded.MaxUnusedJobs'
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
+# 当前操作不满足条件被阻止。
+OPERATIONDENIED_BIZOPERATIONDENIEDERROR = 'OperationDenied.BizOperationDeniedError'
+
 # 任务操作失败。
 OPERATIONDENIED_JOBOPERATIONDENIEDERROR = 'OperationDenied.JobOperationDeniedError'
 
@@ -100,3 +115,6 @@ UNAUTHORIZEDOPERATION_NOTENOUGHPRIVILEGES = 'UnauthorizedOperation.NotEnoughPriv
 
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
+# 自研上云用户创建迁移任务时未指定标签，需要补齐“运营部门”、“运营产品”、“负责人”这三类标签。
+UNSUPPORTEDOPERATION_INTRANETUSERNOTTAGGEDERROR = 'UnsupportedOperation.IntraNetUserNotTaggedError'
