@@ -14,6 +14,9 @@
 # limitations under the License.
 
 
+# CAM签名/鉴权错误。
+AUTHFAILURE = 'AuthFailure'
+
 # DryRun 操作，代表请求将会是成功的，只是多传了 DryRun 参数。
 DRYRUNOPERATION = 'DryRunOperation'
 
@@ -29,7 +32,7 @@ FAILEDOPERATION_AGENOTACHIEVENORMALLEGAL = 'FailedOperation.AgeNotAchieveNormalL
 # 流程已关联文档。
 FAILEDOPERATION_FLOWHASDOCUMENT = 'FailedOperation.FlowHasDocument'
 
-# 模版无资源信息。
+# 模板无资源信息。
 FAILEDOPERATION_TEMPLATEHASNORESOURCE = 'FailedOperation.TemplateHasNoResource'
 
 # 内部错误。
@@ -41,6 +44,9 @@ INTERNALERROR_CACHE = 'InternalError.Cache'
 # 数据库异常。
 INTERNALERROR_DB = 'InternalError.Db'
 
+# 数据库新增记录出错。
+INTERNALERROR_DBINSERT = 'InternalError.DbInsert'
+
 # 内部错误,数据库查询失败,请稍后重试。
 INTERNALERROR_DBREAD = 'InternalError.DbRead'
 
@@ -128,6 +134,9 @@ OPERATIONDENIED_FORBID = 'OperationDenied.Forbid'
 # 未通过个人实名认证。
 OPERATIONDENIED_NOIDENTITYVERIFY = 'OperationDenied.NoIdentityVerify'
 
+# 用户未登录,请先登录后再操作。
+OPERATIONDENIED_NOLOGIN = 'OperationDenied.NoLogin'
+
 # 流程配额不足。
 OPERATIONDENIED_NOQUOTA = 'OperationDenied.NoQuota'
 
