@@ -77,6 +77,9 @@ FAILEDOPERATION_PROTOCOLCHECKERR = 'FailedOperation.ProtocolCheckErr'
 # 收件人已退订。
 FAILEDOPERATION_RECEIVERHASUNSUBSCRIBED = 'FailedOperation.ReceiverHasUnsubscribed'
 
+# 邮件被收信人拒绝。
+FAILEDOPERATION_REJECTEDBYRECIPIENTS = 'FailedOperation.RejectedByRecipients'
+
 # 您的发送遇到问题，请联系腾讯云提交工单沟通原因并解决。
 FAILEDOPERATION_SENDEMAILERR = 'FailedOperation.SendEmailErr'
 
@@ -176,6 +179,9 @@ INVALIDPARAMETERVALUE_TEMPLATENAMEISNULL = 'InvalidParameterValue.TemplateNameIs
 # 不存在该模板，请先创建模板。
 INVALIDPARAMETERVALUE_TEMPLATENOTEXIST = 'InvalidParameterValue.TemplateNotExist'
 
+# 模板变量与收件人列表参数不一一对应。
+INVALIDPARAMETERVALUE_TEMPLATENOTMATCHDATA = 'InvalidParameterValue.TemplateNotMatchData'
+
 # 搜索日期错误，请检查日期及格式是否有效。
 INVALIDPARAMETERVALUE_WRONGDATE = 'InvalidParameterValue.WrongDate'
 
